--[[

Interface: 1.4.4.0 1.4.4RC8

Author: GtX | Andy
Date: 25.07.2017
Version: 1.0

MP - Tested Error Free

Support: http://ls-modcompany.com

History:
V 1.0 @ 25.07.2017 - Beta Release

About: 
Ability to lock or unlock mouse controlled tools on vehicles. If you want to render a flashing warning if input is detected when tools are locked then
you can add     <lockMovingTools renderText="true" />     to you vehicle.xml

All settings are saved with your savegame.

--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	EXAMPLE FOR MODDESC:
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

<specializations>
	<specialization name="lockMovingTools"	 		className="lockMovingTools"    	  	filename="scripts/lockMovingTools.lua"/>
</specializations>


<l10n>
	<text name="input_TOGGLE_TOOLSLOCK">
		<en>Mirrors %s</en>
		<de>Spiegel %s</de>
		<fr>Miroirs %s</fr>
		<es>Espejos %s</es>
		<it>Specchietti %s</it>
	</text>
	
	<text name="TOOLSLOCK_LOCKED">
		<en>Locked</en>
		<de>Verriegelt</de>
		<fr>verrouillés</fr>
		<es>bloqueados</es>
		<it>bloccati</it>
	</text>
	
	<text name="TOOLSLOCK_UNLOCKED">
		<en>Unlocked</en>
		<de>Entriegelt</de>
		<fr>déverrouillés</fr>
		<es>desbloqueados</es>
		<it>sbloccati</it>
	</text>
</l10n>

<inputBindings>
	<input name="TOGGLE_TOOLSLOCK"		category="VEHICLE"		key1="KEY_lctrl KEY_o" 		key2="" button="" device="0" mouse="" />
</inputBindings>

--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
--	END
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

]]

lockMovingTools = {};

function lockMovingTools.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Cylindered, specializations);
end

function lockMovingTools:load(savegame)

	self.lmt = {};
	
	self.lmt.toolState = 1;

	self.lmt.modeMessage = g_i18n:getText("input_TOGGLE_TOOLSLOCK");
	self.lmt.lockedMessage = g_i18n:getText("TOOLSLOCK_LOCKED");
    self.lmt.unlockedMessage = g_i18n:getText("TOOLSLOCK_UNLOCKED");
	
	self.lmt.flashWarning = Utils.getNoNil(getXMLBool(self.xmlFile, "vehicle.lockMovingTools#renderText"), false)
	
	if savegame ~= nil then
		local setMode = getXMLInt(savegame.xmlFile, savegame.key.."#toolsLockedState");
		if setMode ~= nil then
			self.lmt.toolState = setMode;
		end;
	end;
	
end;

function lockMovingTools:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'toolsLockedState="'..tostring(self.lmt.toolState)..'" ';
		
    local nodes = "";

    return attributes, nodes;
end

function lockMovingTools:delete()
end;

function lockMovingTools:update(dt)

	if self.lmt.toolState == 0 then
		self.lmt.toolState = 1
	end;
	
	if self:getIsActive() then
        if self.isClient and self:getIsActiveForInput(false) and not self:hasInputConflictWithSelection() then
			if self.movingTools ~= nil then		
				if InputBinding.hasEvent(InputBinding.TOGGLE_TOOLSLOCK) then
					self.lmt.toolState = self.lmt.toolState + 1;
					if self.lmt.toolState > 2 then
						self.lmt.toolState = 1;
					end;
				end;
			
				for _, tool in pairs(self.movingTools) do
					if tool.axisActionIndex ~= nil then
						if self.lmt.toolState == 1 then
							tool.isActive = false
						else
							tool.isActive = true
						end;
						
						if self.lmt.toolState == 1 and self.lmt.flashWarning then
							local move = InputBinding.getInputAxis(tool.axisActionIndex)
							local isAxisZero = InputBinding.isAxisZero(move);
							if not isAxisZero then
								g_currentMission:showBlinkingWarning(string.format(self.lmt.modeMessage, self.lmt.lockedMessage));
							end
						end
					end
				end;
			end;
		end;
	end;
end;

function lockMovingTools:draw()
	if self.movingTools ~= nil then
		if self:getIsActiveForInput(true) then
			if self.lmt.toolState == 1 then
				g_currentMission:addHelpButtonText(string.format(self.lmt.modeMessage, self.lmt.lockedMessage), InputBinding.TOGGLE_TOOLSLOCK);
			elseif self.lmt.toolState == 2 then
				g_currentMission:addHelpButtonText(string.format(self.lmt.modeMessage, self.lmt.unlockedMessage), InputBinding.TOGGLE_TOOLSLOCK);
			end;
		end;
	end;
end;

function lockMovingTools:readStream(streamId, connection)end;
function lockMovingTools:writeStream(streamId, connection)end;
function lockMovingTools:readUpdateStream(streamId, timestamp, connection)end;
function lockMovingTools:writeUpdateStream(streamId, connection, dirtyMask)end;
function lockMovingTools:mouseEvent(posX, posY, isDown, isUp, button)end;
function lockMovingTools:keyEvent(unicode, sym, modifier, isDown)end;